@@ -1,8 +1,12 @@
 import json
+import logging
 from typing import List
-from pydantic import HttpUrl, validate_arguments, ValidationError
+from pydantic import HttpUrl, validate_arguments
 from pyprediktormapclient.shared import request_from_api
 
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.NullHandler())
+
 
 class ModelIndex:
     """Helper functions to access the ModelIndex API server
@@ -11,7 +15,6 @@ class ModelIndex:
         url (str): The URL of the ModelIndex server with the trailing slash
 
     Todo:
-        * Add logging
         * Validate combination of url and endpoint
     """
 
